# Contributions
Firstly, thank you for taking the time and expressing interest in contributing to the Blankly project 🎉🎉!

***Before you contribute* we need you to sign the CLA.**

Contributions are welcome. To ensure a quick and easy merge, just make sure you look through the way the files are 
organized, and you make the changes where they make sense and are easy to maintain!


### Easy Contributions Right Now
- Testing out API endpoints
    - You can test out the endpoints we have provided and make sure everything works as intended. If there are some 
    subtle flaws, just make a pull!
- Adding new exchanges
    - Try adding exchanges or new endpoints to the ones that we're missing. Adding price data from different trading
      services can be extremely useful for the community.
    - We're currently skipping over deposit, withdrawal and transfer endpoints because the vulnerabilities created 
    for the software aren't currently clear. If you think you see a safe way to implement these, open a suggestion.
      
